//
//  YachApi.h
//  YachOpenSDK
//
//  Created by lifengfeng on 2020/11/11.
//  Copyright © 2020 100Tal. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "YachApiObject.h"

/// 🔔【温馨提示】为了确保 SDK 功能完整，记得在 Info.plist 中配置 LSApplicationQueriesSchemes，添加 yach 和 yachopensdk


/** 接收并处理来至「知音楼」的事件消息
 *  YachApiDelegate 会在 handleOpenURL 中使用并触发
 */
@protocol YachApiDelegate <NSObject>

/// 「知音楼」响应回调
/// @param resp 具体的回应内容
- (void)onResp:(BaseResp *)resp;

@end


@interface YachApi : NSObject

/// 注册应用
/// @param appid 第三方应用在「知音楼」开放平台注册的 appid
+ (BOOL)registerApp:(NSString *)appid;

/// 向「知音楼」发起请求
/// @param req 请求内容
/// @return 成功 YES，失败 NO
+ (BOOL)sendReq:(BaseReq *)req;

/// 处理「知音楼」通过 URL 跳转回 App 时传递的数据
/// @param url 启动 App 的 URL
/// @param delegate YachApiDelegate 代理，用来接收「知音楼」回调的内容
/// @return 成功 YES，失败 NO
+ (BOOL)handleOpenURL:(NSURL *)url delegate:(id<YachApiDelegate>)delegate;



/// 打开「知音楼」，注意，这里仅仅是打开知音楼，如果想跳转到「知音楼」授权登录，请使用 sendReq: 方法
/// @return 打开成功 YES，失败 NO
+ (BOOL)openYachApp;

/// 当前设备是否已安装「知音楼」
+ (BOOL)isYachAppInstalled;

/// 当前设备安装的「知音楼」版本是否支持 OpenApi （可以用来判断设备当前安装的「知音楼」是否支持授权登录）
+ (BOOL)isYachAppSupportApi;

/// 获取「知音楼」下载链接
+ (NSString *)getYachAppInstallUrl;

/// 获取「知音楼」AppStore 链接
+ (NSString *)getYachAppStoreUrl;

/// 获取当前 SDK 版本号
+ (NSString *)getApiVersion;

/// 停止输出 Log（默认 SDK 会打印一些 log 便于开发中快速定位问题）
+ (void)stopLog;

/// 是否在必要情况下（如：当前设备未安装「知音楼」或已安装但版本过低）自动跳转到「知音楼」下载页（用系统浏览器打开）
/// @param autoRedirect 是否自动跳转，默认为 YES，传 NO 后，不会自动跳转到下载页
+ (void)autoRedirectToDownloadPage:(BOOL)autoRedirect;

@end
